﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ram/RAM_EXPORTS.h>
#include <aws/ram/RAMRequest.h>
#include <aws/ram/model/ResourceOwner.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace RAM
{
namespace Model
{

  /**
   */
  class AWS_RAM_API ListResourcesRequest : public RAMRequest
  {
  public:
    ListResourcesRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "ListResources"; }

    Aws::String SerializePayload() const override;


    /**
     * <p>The type of owner.</p>
     */
    inline const ResourceOwner& GetResourceOwner() const{ return m_resourceOwner; }

    /**
     * <p>The type of owner.</p>
     */
    inline bool ResourceOwnerHasBeenSet() const { return m_resourceOwnerHasBeenSet; }

    /**
     * <p>The type of owner.</p>
     */
    inline void SetResourceOwner(const ResourceOwner& value) { m_resourceOwnerHasBeenSet = true; m_resourceOwner = value; }

    /**
     * <p>The type of owner.</p>
     */
    inline void SetResourceOwner(ResourceOwner&& value) { m_resourceOwnerHasBeenSet = true; m_resourceOwner = std::move(value); }

    /**
     * <p>The type of owner.</p>
     */
    inline ListResourcesRequest& WithResourceOwner(const ResourceOwner& value) { SetResourceOwner(value); return *this;}

    /**
     * <p>The type of owner.</p>
     */
    inline ListResourcesRequest& WithResourceOwner(ResourceOwner&& value) { SetResourceOwner(std::move(value)); return *this;}


    /**
     * <p>The principal.</p>
     */
    inline const Aws::String& GetPrincipal() const{ return m_principal; }

    /**
     * <p>The principal.</p>
     */
    inline bool PrincipalHasBeenSet() const { return m_principalHasBeenSet; }

    /**
     * <p>The principal.</p>
     */
    inline void SetPrincipal(const Aws::String& value) { m_principalHasBeenSet = true; m_principal = value; }

    /**
     * <p>The principal.</p>
     */
    inline void SetPrincipal(Aws::String&& value) { m_principalHasBeenSet = true; m_principal = std::move(value); }

    /**
     * <p>The principal.</p>
     */
    inline void SetPrincipal(const char* value) { m_principalHasBeenSet = true; m_principal.assign(value); }

    /**
     * <p>The principal.</p>
     */
    inline ListResourcesRequest& WithPrincipal(const Aws::String& value) { SetPrincipal(value); return *this;}

    /**
     * <p>The principal.</p>
     */
    inline ListResourcesRequest& WithPrincipal(Aws::String&& value) { SetPrincipal(std::move(value)); return *this;}

    /**
     * <p>The principal.</p>
     */
    inline ListResourcesRequest& WithPrincipal(const char* value) { SetPrincipal(value); return *this;}


    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline const Aws::String& GetResourceType() const{ return m_resourceType; }

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline bool ResourceTypeHasBeenSet() const { return m_resourceTypeHasBeenSet; }

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline void SetResourceType(const Aws::String& value) { m_resourceTypeHasBeenSet = true; m_resourceType = value; }

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline void SetResourceType(Aws::String&& value) { m_resourceTypeHasBeenSet = true; m_resourceType = std::move(value); }

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline void SetResourceType(const char* value) { m_resourceTypeHasBeenSet = true; m_resourceType.assign(value); }

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline ListResourcesRequest& WithResourceType(const Aws::String& value) { SetResourceType(value); return *this;}

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline ListResourcesRequest& WithResourceType(Aws::String&& value) { SetResourceType(std::move(value)); return *this;}

    /**
     * <p>The resource type.</p> <p>Valid values: <code>codebuild:Project</code> |
     * <code>codebuild:ReportGroup</code> | <code>ec2:CapacityReservation</code> |
     * <code>ec2:DedicatedHost</code> | <code>ec2:Subnet</code> |
     * <code>ec2:TrafficMirrorTarget</code> | <code>ec2:TransitGateway</code> |
     * <code>imagebuilder:Component</code> | <code>imagebuilder:Image</code> |
     * <code>imagebuilder:ImageRecipe</code> |
     * <code>license-manager:LicenseConfiguration</code> I
     * <code>resource-groups:Group</code> | <code>rds:Cluster</code> |
     * <code>route53resolver:ResolverRule</code> </p>
     */
    inline ListResourcesRequest& WithResourceType(const char* value) { SetResourceType(value); return *this;}


    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline const Aws::Vector<Aws::String>& GetResourceArns() const{ return m_resourceArns; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline bool ResourceArnsHasBeenSet() const { return m_resourceArnsHasBeenSet; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline void SetResourceArns(const Aws::Vector<Aws::String>& value) { m_resourceArnsHasBeenSet = true; m_resourceArns = value; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline void SetResourceArns(Aws::Vector<Aws::String>&& value) { m_resourceArnsHasBeenSet = true; m_resourceArns = std::move(value); }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline ListResourcesRequest& WithResourceArns(const Aws::Vector<Aws::String>& value) { SetResourceArns(value); return *this;}

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline ListResourcesRequest& WithResourceArns(Aws::Vector<Aws::String>&& value) { SetResourceArns(std::move(value)); return *this;}

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline ListResourcesRequest& AddResourceArns(const Aws::String& value) { m_resourceArnsHasBeenSet = true; m_resourceArns.push_back(value); return *this; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline ListResourcesRequest& AddResourceArns(Aws::String&& value) { m_resourceArnsHasBeenSet = true; m_resourceArns.push_back(std::move(value)); return *this; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resources.</p>
     */
    inline ListResourcesRequest& AddResourceArns(const char* value) { m_resourceArnsHasBeenSet = true; m_resourceArns.push_back(value); return *this; }


    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline const Aws::Vector<Aws::String>& GetResourceShareArns() const{ return m_resourceShareArns; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline bool ResourceShareArnsHasBeenSet() const { return m_resourceShareArnsHasBeenSet; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline void SetResourceShareArns(const Aws::Vector<Aws::String>& value) { m_resourceShareArnsHasBeenSet = true; m_resourceShareArns = value; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline void SetResourceShareArns(Aws::Vector<Aws::String>&& value) { m_resourceShareArnsHasBeenSet = true; m_resourceShareArns = std::move(value); }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline ListResourcesRequest& WithResourceShareArns(const Aws::Vector<Aws::String>& value) { SetResourceShareArns(value); return *this;}

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline ListResourcesRequest& WithResourceShareArns(Aws::Vector<Aws::String>&& value) { SetResourceShareArns(std::move(value)); return *this;}

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline ListResourcesRequest& AddResourceShareArns(const Aws::String& value) { m_resourceShareArnsHasBeenSet = true; m_resourceShareArns.push_back(value); return *this; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline ListResourcesRequest& AddResourceShareArns(Aws::String&& value) { m_resourceShareArnsHasBeenSet = true; m_resourceShareArns.push_back(std::move(value)); return *this; }

    /**
     * <p>The Amazon Resource Names (ARN) of the resource shares.</p>
     */
    inline ListResourcesRequest& AddResourceShareArns(const char* value) { m_resourceShareArnsHasBeenSet = true; m_resourceShareArns.push_back(value); return *this; }


    /**
     * <p>The token for the next page of results.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The token for the next page of results.</p>
     */
    inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }

    /**
     * <p>The token for the next page of results.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }

    /**
     * <p>The token for the next page of results.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }

    /**
     * <p>The token for the next page of results.</p>
     */
    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }

    /**
     * <p>The token for the next page of results.</p>
     */
    inline ListResourcesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The token for the next page of results.</p>
     */
    inline ListResourcesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The token for the next page of results.</p>
     */
    inline ListResourcesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    /**
     * <p>The maximum number of results to return with a single call. To retrieve the
     * remaining results, make another call with the returned <code>nextToken</code>
     * value.</p>
     */
    inline int GetMaxResults() const{ return m_maxResults; }

    /**
     * <p>The maximum number of results to return with a single call. To retrieve the
     * remaining results, make another call with the returned <code>nextToken</code>
     * value.</p>
     */
    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }

    /**
     * <p>The maximum number of results to return with a single call. To retrieve the
     * remaining results, make another call with the returned <code>nextToken</code>
     * value.</p>
     */
    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }

    /**
     * <p>The maximum number of results to return with a single call. To retrieve the
     * remaining results, make another call with the returned <code>nextToken</code>
     * value.</p>
     */
    inline ListResourcesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}

  private:

    ResourceOwner m_resourceOwner;
    bool m_resourceOwnerHasBeenSet;

    Aws::String m_principal;
    bool m_principalHasBeenSet;

    Aws::String m_resourceType;
    bool m_resourceTypeHasBeenSet;

    Aws::Vector<Aws::String> m_resourceArns;
    bool m_resourceArnsHasBeenSet;

    Aws::Vector<Aws::String> m_resourceShareArns;
    bool m_resourceShareArnsHasBeenSet;

    Aws::String m_nextToken;
    bool m_nextTokenHasBeenSet;

    int m_maxResults;
    bool m_maxResultsHasBeenSet;
  };

} // namespace Model
} // namespace RAM
} // namespace Aws
